<?php

namespace App\Controller;

use App\Entity\Dimension;
use App\Form\DimensionType;
use App\Repository\DimensionRepository;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Attribute\Route;

#[Route('/dimension')]
final class DimensionController extends AbstractController
{
    #[Route(name: 'app_dimension_index', methods: ['GET'])]
    public function index(DimensionRepository $dimensionRepository): Response
    {
        return $this->render('dimension/index.html.twig', [
            'dimensions' => $dimensionRepository->findAll(),
        ]);
    }

    #[Route('/new', name: 'app_dimension_new', methods: ['GET', 'POST'])]
    public function new(Request $request, EntityManagerInterface $entityManager): Response
    {
        $dimension = new Dimension();
        $form = $this->createForm(DimensionType::class, $dimension);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $entityManager->persist($dimension);
            $entityManager->flush();

            return $this->redirectToRoute('app_dimension_index', [], Response::HTTP_SEE_OTHER);
        }

        return $this->render('dimension/new.html.twig', [
            'dimension' => $dimension,
            'form' => $form,
        ]);
    }

    #[Route('/{id}', name: 'app_dimension_show', methods: ['GET'])]
    public function show(Dimension $dimension): Response
    {
        return $this->render('dimension/show.html.twig', [
            'dimension' => $dimension,
        ]);
    }

    #[Route('/{id}/edit', name: 'app_dimension_edit', methods: ['GET', 'POST'])]
    public function edit(Request $request, Dimension $dimension, EntityManagerInterface $entityManager): Response
    {
        $form = $this->createForm(DimensionType::class, $dimension);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $entityManager->flush();

            return $this->redirectToRoute('app_dimension_index', [], Response::HTTP_SEE_OTHER);
        }

        return $this->render('dimension/edit.html.twig', [
            'dimension' => $dimension,
            'form' => $form,
        ]);
    }

    #[Route('/{id}', name: 'app_dimension_delete', methods: ['POST'])]
    public function delete(Request $request, Dimension $dimension, EntityManagerInterface $entityManager): Response
    {
        if ($this->isCsrfTokenValid('delete'.$dimension->getId(), $request->getPayload()->getString('_token'))) {
            $entityManager->remove($dimension);
            $entityManager->flush();
        }

        return $this->redirectToRoute('app_dimension_index', [], Response::HTTP_SEE_OTHER);
    }
}
