<?php

namespace App\Controller;

use App\Entity\ReponseUtilisateur;
use App\Form\ReponseUtilisateurType;
use App\Repository\ReponseUtilisateurRepository;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Attribute\Route;

#[Route('/reponse/utilisateur')]
final class ReponseUtilisateurController extends AbstractController
{
    #[Route(name: 'app_reponse_utilisateur_index', methods: ['GET'])]
    public function index(ReponseUtilisateurRepository $reponseUtilisateurRepository): Response
    {
        return $this->render('reponse_utilisateur/index.html.twig', [
            'reponse_utilisateurs' => $reponseUtilisateurRepository->findAll(),
        ]);
    }

    #[Route('/new', name: 'app_reponse_utilisateur_new', methods: ['GET', 'POST'])]
    public function new(Request $request, EntityManagerInterface $entityManager): Response
    {
        $reponseUtilisateur = new ReponseUtilisateur();
        $form = $this->createForm(ReponseUtilisateurType::class, $reponseUtilisateur);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $entityManager->persist($reponseUtilisateur);
            $entityManager->flush();

            return $this->redirectToRoute('app_reponse_utilisateur_index', [], Response::HTTP_SEE_OTHER);
        }

        return $this->render('reponse_utilisateur/new.html.twig', [
            'reponse_utilisateur' => $reponseUtilisateur,
            'form' => $form,
        ]);
    }

    #[Route('/{id}', name: 'app_reponse_utilisateur_show', methods: ['GET'])]
    public function show(ReponseUtilisateur $reponseUtilisateur): Response
    {
        return $this->render('reponse_utilisateur/show.html.twig', [
            'reponse_utilisateur' => $reponseUtilisateur,
        ]);
    }

    #[Route('/{id}/edit', name: 'app_reponse_utilisateur_edit', methods: ['GET', 'POST'])]
    public function edit(Request $request, ReponseUtilisateur $reponseUtilisateur, EntityManagerInterface $entityManager): Response
    {
        $form = $this->createForm(ReponseUtilisateurType::class, $reponseUtilisateur);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $entityManager->flush();

            return $this->redirectToRoute('app_reponse_utilisateur_index', [], Response::HTTP_SEE_OTHER);
        }

        return $this->render('reponse_utilisateur/edit.html.twig', [
            'reponse_utilisateur' => $reponseUtilisateur,
            'form' => $form,
        ]);
    }

    #[Route('/{id}', name: 'app_reponse_utilisateur_delete', methods: ['POST'])]
    public function delete(Request $request, ReponseUtilisateur $reponseUtilisateur, EntityManagerInterface $entityManager): Response
    {
        if ($this->isCsrfTokenValid('delete'.$reponseUtilisateur->getId(), $request->getPayload()->getString('_token'))) {
            $entityManager->remove($reponseUtilisateur);
            $entityManager->flush();
        }

        return $this->redirectToRoute('app_reponse_utilisateur_index', [], Response::HTTP_SEE_OTHER);
    }
}
